﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'tr', {
	auto: 'Otomatik',
	bgColorTitle: 'Arka Renk',
	colors: {
		'000': 'Siyah',
		'800000': 'Kestane',
		'8B4513': 'Koyu Kahverengi',
		'2F4F4F': 'Koyu Kurşuni Gri',
		'008080': 'Teal',
		'000080': 'Mavi',
		'4B0082': 'Çivit Mavisi',
		'696969': 'Silik Gri',
		B22222: 'Ateş Tuğlası',
		A52A2A: 'Kahverengi',
		DAA520: 'Altun Sırık',
		'006400': 'Koyu Yeşil',
		'40E0D0': 'Turkuaz',
		'0000CD': 'Orta Mavi',
		'800080': 'Pembe',
		'808080': 'Gri',
		F00: 'Kırmızı',
		FF8C00: 'Koyu Portakal',
		FFD700: 'Altın',
		'008000': 'Yeşil',
		'0FF': 'Ciyan',
		'00F': 'Mavi',
		EE82EE: 'Menekşe',
		A9A9A9: 'Loş Gri',
		FFA07A: 'Açık Sarımsı',
		FFA500: 'Portakal',
		FFFF00: 'Sarı',
		'00FF00': 'Açık Yeşil',
		AFEEEE: 'Sönük Turkuaz',
		ADD8E6: 'Açık Mavi',
		DDA0DD: 'Mor',
		D3D3D3: 'Açık Gri',
		FFF0F5: 'Eflatun Pembe',
		FAEBD7: 'Antik Beyaz',
		FFFFE0: 'Açık Sarı',
		F0FFF0: 'Balsarısı',
		F0FFFF: 'Gök Mavisi',
		F0F8FF: 'Reha Mavi',
		E6E6FA: 'Eflatun',
		FFF: 'Beyaz',
		'1ABC9C': 'Koyu Camgöbeği',
		'2ECC71': 'Zümrüt Yeşili',
		'3498DB': 'Parlak Mavi',
		'9B59B6': 'Ametist Moru',
		'4E5F70': 'Kirli Gri Mavi',
		'F1C40F': 'Canlı Sarı',
		'16A085': 'Koyu Camgöbeği',
		'27AE60': 'Koyu Zümrüt Yeşili',
		'2980B9': 'Koyu Mavi',
		'8E44AD': 'Koyu Menekşe',
		'2C3E50': 'Koyu Lacivert',
		'F39C12': 'Turuncu',
		'E67E22': 'Havuç Turuncusu',
		'E74C3C': 'Soluk Kırmızı',
		'ECF0F1': 'Parlak Gümüş',
		'95A5A6': 'Açık Kirli Gri Camgöbeği',
		'DDD': 'Açık Gri',
		'D35400': 'Balkabağı Turuncusu',
		'C0392B': 'Kan Kırmızı',
		'BDC3C7': 'Gümüş',
		'7F8C8D': 'Kirli Gri Camgöbeği',
		'999': 'Koyu Gri'
	},
	more: 'Diğer renkler...',
	panelTitle: 'Renkler',
	textColorTitle: 'Yazı Rengi'
} );
